import { StorageDepositArgs } from '@tonic-foundation/storage';
import BN from 'bn.js';
import { Account } from 'near-api-js';
import { PrepareBatch } from './batch';
import { TonicContract } from './contract';
import { Market } from './market';
import { ExchangeBalances, MarketId, OpenLimitOrder, OrderId, Orderbook } from './types';
import { MarketViewV1, NewOrderParamsV1, OrderResultV1, SwapParamsV1, ActionResultV1, FTMessage } from './types/v1';
declare type AnyExcept<T = any, E = never> = T extends E ? never : T;
export declare class Tonic {
    readonly account: Account;
    readonly contractId: string;
    private _contract;
    constructor(account: Account, contractId: string);
    get contract(): TonicContract;
    /**
     * This function calls a change method, returning both the return value of the
     * call and the execution outcome. Provide the `contractId` property to call a
     * different contract, defaults to the Tonic DEX.
     *
     * Many use cases need transaction/receipt IDs after calling a change
     * method, which makes the NEAR SDK's Contract class unsuitable.
     * https://github.com/near/near-api-js/blob/c84aef6cc18fe5ac1063411c95283ba3130fa656/src/contract.ts#L145
     */
    private functionCallWithOutcome;
    /**
     * Execute batch actions. See the example in the "examples" directory for more
     * information.
     */
    executeBatch(batch: PrepareBatch): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: ActionResultV1[];
    }>;
    /**
     * Deposit NEAR for storage staking. We recommend depositing 0.1 NEAR at a
     * time to give users some room to place orders.
     *
     * Pass `amount` as a decimal amount of NEAR to deposit, eg, 0.1.
     *
     * Passing `registrationOnly` causes deposit in excess of the minimum required
     * balance to be refunded. The minimum balance is computed at runtime, so it's
     * recommended to pass at least 0.01 NEAR to avoid issues.
     *
     * The account to deposit for can be specified with `accountId`. Omit it to
     * deposit for the caller's account.
     */
    storageDeposit(params: StorageDepositArgs): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        result: import("@tonic-foundation/storage").StorageBalance<BN>;
    }>;
    /**
     * Create a market
     */
    createMarket(params: {
        baseTokenId: string;
        quoteTokenId: string;
        baseTokenLotSize: string;
        quoteTokenLotSize: string;
        takerFeeBaseRate: number;
        makerRebateBaseRate: number;
    }): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: string;
    }>;
    /**
     * Place an order. This is a relatively low-level method that works with
     * lot-aware values. Client applications may use Market.placeOrder instead for
     * a higher-level interface.
     */
    placeOrder(market_id: MarketId, order: NewOrderParamsV1): Promise<{
        response: OrderResultV1;
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
    }>;
    /**
     * Cancel an order.
     */
    cancelOrder(market_id: MarketId, order_id: OrderId): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: unknown;
    }>;
    /**
     * Cancel multiple orders in a market. Use Tonic.executeBatch
     * to cancel orders in multiple markets.
     */
    cancelOrders(marketId: MarketId, orderIds: OrderId[]): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: ActionResultV1[];
    }>;
    /**
     * Cancel all orders in a market.
     */
    cancelAllOrders(market_id: MarketId): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: unknown;
    }>;
    /**
     * Deposit NEP 141 tokens or native NEAR. For native NEAR, the `tokenId` must
     * be 'NEAR'.
     *
     * The amount must be decimal-aware, eg, to deposit 1 NEAR (24 decimals), use
     *
     * ```
     * import { decimalToBn } from '@tonic-foundation/utils';
     * // Deposit 1 NEAR
     * tonic.deposit('NEAR', decimalToBn(1, 24))
     * // Deposit 1 USDC
     * tonic.deposit('usdc.example.testnet', decimalToBn(1, 6))
     * ```
     */
    deposit(tokenId: string, amount: BN): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    /**
     * Deposit NEP-141 token.
     */
    depositFt(tokenId: string, amount: BN, msg?: AnyExcept<FTMessage, string>): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    swap(tokenId: string, amount: BN, params: SwapParamsV1): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    /**
     * Deposit native NEAR.
     */
    depositNear(amount: BN): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    /**
     * Withdraw NEP 141 tokens or native NEAR. For native NEAR, the `tokenId` must
     * be 'NEAR'.
     *
     * The amount must be decimal-aware, eg,
     *
     * ```
     * import { decimalToBn } from '@tonic-foundation/utils';
     * // Withdraw 1 NEAR
     * tonic.withdraw('NEAR', decimalToBn(1, 24))
     * // Withdraw 1 USDC
     * tonic.withdraw('usdc.example.testnet', decimalToBn(1, 6))
     * ```
     */
    withdraw(tokenId: string, amount: BN): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    withdrawFt(tokenId: string, amount: BN): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    withdrawNear(amount: BN): Promise<{
        executionOutcome: import("near-api-js/lib/providers").FinalExecutionOutcome;
        response: any;
    }>;
    /**
     * Get the orderbook. Orders are returned with decimals (eg, 1 USDC is
     * returned as 1000000). The format of each order is [price, open quantity].
     *
     * @param market_id
     * @param depth Number of price levels to fetch, default 12
     * @returns
     */
    getOrderbook(market_id: MarketId, depth?: number): Promise<Orderbook>;
    getOpenOrders(market_id: MarketId): Promise<OpenLimitOrder[]>;
    getMarket(marketId: MarketId): Promise<Market>;
    /**
     * List markets in order of creation.
     */
    listMarkets(offset?: number, limit?: number): Promise<MarketViewV1[]>;
    /**
     * Return available exchange balances with decimals as a map of { tokenId =>
     * balance }. "Available balance" is balance not currently locked in an open
     * order. For example, an account with 1 USDC available would see
     *
     * ```
     * await tonic.getBalances() // { usdc.example.testnet: BN<1000000> }
     * ```
     */
    getBalances(): Promise<ExchangeBalances>;
}
export declare function prepareNewOrderV1(params: NewOrderParamsV1): NewOrderParamsV1;
export {};
